
// Moon Secrets LED Jacket by Becky Stern
// based on sample NeoPixel code by Phillip Burgess & Adafruit Industries

#include <Wire.h>
#include <Adafruit_NeoPixel.h>
 
#define PIN 6
#define TPIXEL 131 //The total amount of pixels/leds in your connected strip/stick (Default is 60)
 
int switchPin = 10; // switch is connected to pin 10
int val; // variable for reading the pin status
int lightMode = 0; // which animation is being displayed
int replay = 1; // trigger animation that occurs at beginning of motif

int brightness = 200; //adjust brightness here

// Here is where you can put in your favorite colors that will appear!
// just add new {nnn, nnn, nnn}, lines. They will be picked out randomly
//                          R   G   B
uint8_t myColors[][3] = {{250, 255, 255},   // 
                         {250, 255, 255},   // 
                         {250, 255, 255},   // 
                          };
                               
// don't edit the line below
#define FAVCOLORS sizeof(myColors) / 3
 
Adafruit_NeoPixel strip = Adafruit_NeoPixel(TPIXEL, PIN, NEO_GRB + NEO_KHZ800);
// our RGB -> eye-recognized gamma color
byte gammatable[256];

//these tables describe the addresses of the different elements of the design, all starting at the center front
int outerRight[] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33};
int middleRight[] = {200, 200, 200, 200, 200, 123, 200, 200, 200, 124, 200, 200, 200, 125, 200, 200, 200, 126};
int innerRight[] = {122, 121, 120, 119, 118, 117, 116, 115, 114, 113, 112, 111, 110, 109, 108, 107, 106, 105, 104, 103, 102, 101, 100, 99, 98, 97, 96, 95, 200, 200, 200, 200, 200, 200, 200};
  
int outerLeft[] = {67, 66, 65, 64, 63, 62, 61, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 47, 46, 45, 44, 43, 42, 41, 40, 39, 38, 37, 36, 35, 34};
int middleLeft[] = {200, 200, 200, 200, 200, 130, 200, 200, 200, 129, 200, 200, 200, 128, 200, 200, 200, 127}; 
int innerLeft[] = {68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 200, 200, 200, 200, 200, 200};
  
void setup() {
pinMode(switchPin, INPUT_PULLUP); // Set the switch pin as input
pinMode(PIN, OUTPUT);
strip.setBrightness(brightness); //adjust brightness here
buttonState = digitalRead(switchPin); // read the initial state
strip.begin();
strip.show(); // Initialize all pixels to 'off'

// thanks PhilB for this gamma table!
// it helps convert RGB colors to what humans see
for (int i=0; i<256; i++) {
float x = i;
x /= 255;
x = pow(x, 2.5);
x *= 255;
gammatable[i] = x;
//Serial.println(gammatable[i]);
}
}
 
 
void loop(){

  val = digitalRead(switchPin); // read input value and store it in val
    if (val==LOW) { // the button state has changed!
          lightMode = 1;
          if (replay == 1){//play the animation only once upon entering this mode
            for(uint16_t i=0; i<2; i++) {
              colorWipe(strip.Color(0, 0, 0), 20);
              colorWipe(strip.Color(0, 0, 255), 30);
             }
          replay = 0;
          }
    
          for(uint16_t i=0; i<strip.numPixels(); i++) {
            strip.setPixelColor(i, strip.Color(0,0,255));
            //delay(wait);
          }
          strip.show();
    }
    if (val==HIGH) {
          lightMode = 2;
          if (replay == 0){//play the animation only once upon entering this mode
            for(uint16_t i=0; i<2; i++) {// this animation is the same as the other one, but could be different for more variable functionality
              colorWipe(strip.Color(0, 0, 0), 20);
              colorWipe(strip.Color(0, 0, 255), 30);
             }
          replay = 1;
          }

            for(uint16_t i=0; i<strip.numPixels(); i++) {
            strip.setPixelColor(i, strip.Color(0,0,255));
            //delay(wait);
            }
            strip.show();
    }
}

// Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
  for(uint16_t i=0; i<35; i++) {
    strip.setPixelColor(outerRight[i], c);
    strip.setPixelColor(outerLeft[i], c);
    strip.setPixelColor(outerRight[i], c);
    strip.setPixelColor(innerLeft[i], c);
    strip.setPixelColor(innerRight[i], c);
    strip.setPixelColor(middleLeft[i], c);
    strip.setPixelColor(middleRight[i], c);
    strip.show();
    delay(wait);

    
  }
  
}
//Theatre-style crawling lights.
void theaterChase(uint8_t wait) {
    for (int q=0; q < 3; q++) {
      for (int i=0; i < strip.numPixels(); i=i+3) {
        strip.setPixelColor(i+q, strip.Color(50,50,50));    //turn every third pixel on
      }
      strip.show();

      delay(wait);

      for (int i=0; i < strip.numPixels(); i=i+3) {
        strip.setPixelColor(i+q, strip.Color(250,255,255));        //turn every third pixel off
      }
    }
  }

//Rainbow Program
void rainbow(uint8_t wait) {
  uint16_t i, j;
 
  for(j=0; j<256; j++) {
    for(i=0; i<strip.numPixels(); i++) {
strip.setPixelColor(i, Wheel((i+j) & 255));
}
strip.show();
    delay(wait);
  }
}

// Rainbow Cycle Program - Equally distributed
void rainbowCycle(uint8_t wait) {
uint16_t i, j;
 
for(j=0; j<256*5; j++) { // 5 cycles of all colors on wheel
for(i=0; i< strip.numPixels(); i++) {
strip.setPixelColor(i, Wheel(((i * 256 / strip.numPixels()) + j) & 255));
}
strip.show();
delay(wait);
}
}
// Input a value 0 to 255 to get a color value.
// The colours are a transition r - g - b - back to r.
uint32_t Wheel(byte WheelPos) {
if(WheelPos < 85) {
return strip.Color(WheelPos * 3, 255 - WheelPos * 3, 0);
} else if(WheelPos < 170) {
WheelPos -= 85;
return strip.Color(255 - WheelPos * 3, 0, WheelPos * 3);
} else {
WheelPos -= 170;
return strip.Color(0, WheelPos * 3, 255 - WheelPos * 3);
}
}

void flashRandom(int wait, uint8_t howmany) {
 
  for(uint16_t i=0; i<howmany; i++) {
    // pick a random favorite color!
    int c = random(FAVCOLORS);
    int red = myColors[c][0];
    int green = myColors[c][1];
    int blue = myColors[c][2]; 
 
    // get a random pixel from the list
    int j = random(strip.numPixels());
    
    // fade out in 5 steps
    for (int x=5; x >= 0; x--) {
      int r = red * x; r /= 5;
      int g = green * x; g /= 5;
      int b = blue * x; b /= 5;
      
      strip.setPixelColor(j, strip.Color(r, g, b));
      strip.show();
      delay(wait);
    }
    // now we will 'fade' it in 5 steps
    for (int x=0; x < 5; x++) {
      int r = red * (x+1); r /= 5;
      int g = green * (x+1); g /= 5;
      int b = blue * (x+1); b /= 5;
      
      strip.setPixelColor(j, strip.Color(r, g, b));
      strip.show();
      delay(wait);
    }
    
  }
}
